@@ -77,7 +77,11 @@
         var content_height = $("#content").outerHeight();
         $("#django-admin-global-sidebar").css("top", header_height + "px");
         $("#django-admin-global-sidebar .django-admin-global-sidebar-collapse-button").css("height", breadcrumbs_height + "px");
-        $("#django-admin-global-sidebar").css("height", content_height + "px");
+        if(breadcrumbs_height){
+            $("#django-admin-global-sidebar").css("height", (breadcrumbs_height + content_height) + "px");
+        }else{
+            $("#django-admin-global-sidebar").css("height", content_height + "px");
+        }
     };
 
     $(document).ready(function(){
